"""Module to hold constants for testing."""
import os

# Handle pathing.
THIS_DIR = os.path.dirname(os.path.abspath(__file__))
CASE_DIR = os.path.join(THIS_DIR, 'cases')
DATA_DIR = os.path.join(THIS_DIR, 'data')
SNIPPET_DIR = os.path.join(THIS_DIR, '..', 'docs', 'rst', 'snippets')
SNIPPET_FILES = [os.path.join(SNIPPET_DIR, x) for x in
                 os.listdir(SNIPPET_DIR) if x.endswith('.rst')]

# Path to IEEE 14 bus model.
PATH_14 = os.path.join(CASE_DIR, 'ieee_14', 'IEEE 14 bus.pwb')

# Path to the Texas 2000 bus model.
PATH_2000 = os.path.join(CASE_DIR, 'tx2000', 'tx2000_base.PWB')
PATH_2000_mod = os.path.join(
    CASE_DIR, 'tx2000_mod', 'ACTIVSg2000_AUG-09-2018_Ride_version7.PWB')

# Path to the WSCC model.
PATH_9 = os.path.join(CASE_DIR, 'wscc_9', 'WSCC 9 bus.pwb')

# Aux file for filtering transformers by LTC control.
LTC_AUX_FILE = os.path.join(THIS_DIR, 'ltc_filter.aux')

# Map cases for doc testing.
CASE_MAP = {'14': PATH_14, '2000': PATH_2000}

# Path to file containing lines for one of the examples.
CANDIDATE_LINES = os.path.join(DATA_DIR, 'CandidateLines.csv')


"""This testing module runs all the code snippets in the
docs/rst/snippets directory."""

import unittest
import doctest

# noinspection PyUnresolvedReferences
from constants import CASE_MAP, SNIPPET_FILES, CANDIDATE_LINES

########################################################################
# DOC TESTS
########################################################################
# The "load_tests" and "get_snippet_suites" methods below take care of
# everything needed to run all the snippets.


# To enable unittest discovery:
# https://docs.python.org/3.8/library/doctest.html#unittest-api
# noinspection PyUnusedLocal
def load_tests(loader, tests, ignore):
    suites = get_snippet_suites()
    for s in suites:
        tests.addTests(s)
    return tests


def get_snippet_suites():
    """Return list of DocFileSuites"""
    out = []
    # Loop over the available cases.
    for suffix, case_path in CASE_MAP.items():
        # Filter files by suffix, which corresponds to the case.
        files = [x for x in SNIPPET_FILES if x.endswith(suffix + '.rst')]

        if len(files) > 0:

            # Define global variables needed for the examples.
            g = {'CASE_PATH': case_path}
            if '2000' in suffix:
                # One example adds lines and depends on a .csv file.
                g['CANDIDATE_LINES'] = CANDIDATE_LINES

            # Create a DocFileSuite.
            out.append(doctest.DocFileSuite(
                *files, module_relative=False,
                globs=g))

    return out


if __name__ == '__main__':
    unittest.main()
